@@ -186,11 +186,10 @@ def build_app_blocks(
     gr.Markdown("This movie recommender adapts to your preferences")
     session = gr.State(value=Session())
     with gr.Row():
-        first_movie_markdown, first_image_url = dispenser.initial_content
-        image = gr.Image(first_image_url, interactive=False)
+        image = gr.Image(dispenser.initial_poster_url, interactive=False)
         image.style(width=200)
         with gr.Column(scale=4):
-            markdown = gr.Markdown(first_movie_markdown)
+            markdown = gr.Markdown(dispenser.initial_markdown)
 
             def build_button(feedback):
                 async def wrapper(session):
