@@ -19,13 +19,16 @@ class MSELoss(RecommendingLossInterface):
         return loss
 
 
+# TODO: actually add confience here
 class MSEConfidenceLoss(RecommendingLossInterface):
     """Loss to pair up with ConfidenceRecommenderBase."""
 
-    def __init__(self, ratings_deviation=1):
+    def __init__(self, confidence=0.9, ratings_deviation=1):
         """
+        :param confidence: the level of confidence that unrated items are irrelevant
         :param ratings_deviation: the parameter of ratings normal distribution
         """
+        self.confidence = confidence
         self.ratings_variance = ratings_deviation**2
 
     def __call__(
